crop_growth_speed

Function crop_growth_speed 

pub(super) fn crop_growth_speed(
    block: BlockRef,
    world: &dyn LevelReader,
    pos: BlockPos,
) -> f32
Calculates Vanilla crop growth speed for the supplied crop block.

Stems use the same farmland and neighboring-crop calculation as crops, but have different survival and mature-growth behavior.